.. _newline_indices-name:

!!!!!!!!!!!!!!!
newline_indices
!!!!!!!!!!!!!!!

.. meta::
   :keywords: newline_indices, find, index, all, newlines, in, string

.. index:: newline_indices, find, index, all, newlines, in, string

.. _newline_indices-title:

Find index of all the newlines in a string
##########################################

.. contents::
   :local:

.. meta::
   :keywords: arguments

.. index:: arguments

.. _newline_indices@Arguments:

Arguments
*********

.. meta::
   :keywords: data

.. index:: data

.. _newline_indices@Arguments@data:

data
====
The string we are searching for newlines.

.. meta::
   :keywords: results

.. index:: results

.. _newline_indices@Results:

Results
*******

.. meta::
   :keywords: newline_list

.. index:: newline_list

.. _newline_indices@Results@newline_list:

newline_list
============
The return newline_list is the list of indices in data that
represent all of the newlines; i.e. '\n'.

.. literalinclude:: ../../xrst/newline_indices.py
   :lines: 28-29
   :language: py

.. literalinclude:: ../../xrst/newline_indices.py
   :lines: 44-47
   :language: py
